@@ -5,7 +5,7 @@ use lib "/prj/dsnew/perlmods/lib/site_perl/current/aix";
 use lib "/prj/dsnew/perlmods/lib/current";
 use lib "./blib/lib";
 
-BEGIN { $| = 1; $Ntst=8; print "1..$Ntst\n"; $tst=1; }
+BEGIN { $| = 1; $Ntst=12; print "1..$Ntst\n"; $tst=1; }
 END { if ( $tst != $Ntst ) { print "not ok $tst\n"; } }
 
 ###############################################################################
@@ -21,6 +21,42 @@ $tst++;
 
 ###############################################################################
 
+$scr->clrscr;
+
+print "setstr test\n\r";
+
+print $scr->setstr("*",10)," - ",length $scr->setstr("*",10),"\n\r";
+print $scr->setstr("A",75)," - ",length $scr->setstr("A",75),"\n\r";
+
+$N=3000;
+$L=1000;
+
+$b=time();
+for (1..$N) {my $line="";
+  for(1..$L) {
+    $line.="*";
+  }
+}
+$e=time()-$b;
+print "$N*$L : $e secs\n\r";
+
+$N=10000;
+
+$b=time();
+for (1..$N) {
+  my $line=$scr->setstr("*",100);
+}
+$e=time()-$b;
+print "$N*setstr($L) : $e secs\n\r";
+
+print "\nAny key to continue:";
+$scr->getch();
+
+print "\n\rok $tst\n";
+$tst++;
+
+###############################################################################
+
 $scr->clrscr();
 
 $scr->at(0,0);
@@ -67,7 +103,7 @@ $tst++;
 $scr->clrscr();
 
 $scr->at(0,0);
-print "Test $tst, input a line of 40 max. (anything allowed), display length=20\n";
+print "Test $tst, input a line of 40 max. (anything allowed), display length=20\n\r";
 print "          Conversion to uppercase.\n";
 
 $scr->at(4,4)->puts(">");
@@ -86,8 +122,8 @@ $tst++;
 $scr->clrscr();
 
 $scr->at(0,0);
-print "Test $tst, input a line of 40 max. (anything allowed), display length=20\n";
-print "          Conversion to lowercase.\n";
+print "Test $tst, input a line of 40 max. (anything allowed), display length=20\n\r";
+print "          Conversion to lowercase.\n\r";
 print "          Value is 'Hi There!' (should be converted)\n";
 
 $scr->at(4,4)->puts(">");
@@ -157,6 +193,81 @@ $tst++;
 
 ###############################################################################
 
+$scr->clrscr();
+
+$scr->at(0,0);
+print "Test $tst, input one letter (A-Z allowed)\n";
+
+$line=$scr->at(4,4)->puts(">")->readline(
+       ROW        => 4,
+       COL        => 6,
+       DISPLAYLEN => 1,
+       LEN        => 1,
+       ONLYVALID  => "[a-zA-Z]+",
+ 
+);
+
+$L=length $line;
+$scr->at(5,5);print "%$line%, len=$L";
+$scr->at(8,4)->puts("Any key to continue.")->getch();
+
+$scr->at(20,0);
+print "ok $tst\n";
+$tst++;
+
+###############################################################################
+
+$scr->clrscr();
+
+$scr->at(0,0);
+print "Test $tst, input one letter (A-Z allowed), without Commit\n";
+
+$line=$scr->at(4,4)->puts(">")->readline(
+       ROW        => 4,
+       COL        => 6,
+       DISPLAYLEN => 1,
+       LEN        => 1,
+       ONLYVALID  => "[a-zA-Z]+",
+       CONVERT    => "up",
+       NOCOMMIT   => 1
+);
+
+$L=length $line;
+$scr->at(5,5);print "%$line%, len=$L";
+$scr->at(8,4)->puts("Any key to continue.")->getch();
+
+$scr->at(20,0);
+print "ok $tst\n";
+$tst++;
+
+###############################################################################
+
+$scr->clrscr();
+
+$scr->at(0,0);
+print "Test $tst, Read only input ;-)\n";
+
+$line=$scr->at(4,4)->puts(">")->readline(
+       ROW        => 4,
+       COL        => 6,
+       DISPLAYLEN => 20,
+       LEN        => 20,
+       ONLYVALID  => "[a-zA-Z]+",
+       CONVERT    => "up",
+       READONLY   => 1,
+       LINE       => "Read only display",
+);
+
+$L=length $line;
+$scr->at(5,5);print "%$line%, len=$L";
+$scr->at(8,4)->puts("Any key to continue.")->getch();
+
+$scr->at(20,0);
+print "ok $tst\n";
+$tst++;
+
+###############################################################################
+
 exit;
 
 
